Repository for Hilltop Python tools
=============================================================

This git repository contains the Hilltop Python tools and associated documentation.

Documentation
--------------
The primary documentation for the package can be found `here <https://hilltop-py.readthedocs.io>`_.

Installation
------------
hilltop-py can be installed via pip or conda::

  pip install hilltop-py

or::

  conda install -c mullenkamp hilltop-py

The main dependency is `pandas <https://pandas.pydata.org/docs/>`_. `pywin32 <https://github.com/mhammond/pywin32>`_ is a dependency if the user wishes to use the COM module, but it is not installed by default.
